# frenchtext
> NLP library to process french text.


This file will become your README and also the index of your documentation.

## Install

`pip install frenchtext`

## How to use

Fill me in please! Don't forget code examples:

```
print("frenchtext is awesome !")
```

    frenchtext is awesome !

